@@ -233,6 +233,21 @@ class BaseTestPlex:
             if exc.ierr != ERR_ARG_OUTOFRANGE:
                 raise
 
+    def testNatural(self):
+        dim = self.plex.getDimension()
+        ct = self.plex.getCellType(0)
+        fe = PETSc.FE().createByCell(dim, 1, ct)
+        self.plex.setField(0, fe)
+        self.plex.createDS()
+        self.plex.setUseNatural(True)
+        self.plex.distribute()
+        self.plex.view()
+        gv = self.plex.createGlobalVec()
+        nv = self.plex.createNaturalVec()
+        self.plex.globalToNaturalBegin(gv, nv)
+        self.plex.globalToNaturalEnd(gv, nv)
+        self.plex.naturalToGlobalBegin(nv, gv)
+        self.plex.naturalToGlobalEnd(nv, gv)
 
 # --------------------------------------------------------------------
 
